
<p align="center">
<img src="https://imgur.com/TDqD4lo.png" width="240px"> 
</p>

<p align="center">

<img src="https://travis-ci.org/MasoniteFramework/core.svg?branch=master">
<img src="https://img.shields.io/badge/python-3.4+-blue.svg" alt="Python Version"> <img src="https://img.shields.io/github/license/MasoniteFramework/core.svg" alt="License"> 
<img src="https://coveralls.io/repos/github/MasoniteFramework/core/badge.svg?branch=master#1" alt="Code Coverage"> 

</p>

----

# Contributing

Contributing to Masonite is simple:
* Hop on [Slack Channel](http://slack.masoniteproject.com/)! to ask any questions you need.
* Read the [How To Contribute](https://masoniteframework.gitbook.io/docs/prologue/how-to-contribute) documentation to see ways to contribute to the project.
* Read the [Contributing Guide](https://masoniteframework.gitbook.io/docs/prologue/contributing-guide) to learn how to contribute to the core source code development of the project.
* Read the [Installation](https://docs.masoniteproject.com/#installation) documentation on how to get started creating a Masonite project.
* Check the open issues and milestones.
* If you have any questions just open up an issue to discuss with the core maintainers.
